@@ -1,6 +1,6 @@
 package Resque::Worker;
 {
-  $Resque::Worker::VERSION = '0.04';
+  $Resque::Worker::VERSION = '0.05';
 }
 use Any::Moose;
 with 'Resque::Encoder';
@@ -311,7 +311,7 @@ sub worker_pids {
     my $self = shift;
     my @pids;
     for ( split "\n", `ps axo pid,command | grep resque | grep -v resque-web` ) {
-        if ( m/^(\d+)\s(.+)$/ ) {
+        if ( m/^\s*(\d+)\s(.+)$/ ) {
             push @pids, $1;
         }
     }
@@ -378,7 +378,7 @@ Resque::Worker - Does the hard work of babysitting Resque::Job's
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 ATTRIBUTES
 
